(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      6945,        237]
NotebookOptionsPosition[      6027,        206]
NotebookOutlinePosition[      6367,        221]
CellTagsIndexPosition[      6324,        218]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"<<", "Fractals`"}]], "Input",
 CellChangeTimes->{{3.39172739546875*^9, 3.3917273974375*^9}, {
  3.3917276194375*^9, 3.391727634046875*^9}}],

Cell["\<\
The following are examples of density plots for different fractals with \
different parameters, later are examples of contour plots of the fractals.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"JuliaPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"MandelbrotPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "0.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1.25"}], ",", "1.25"}], "}"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"MandelbrotPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "0.5"}], ",", "0.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1.25"}], ",", "0"}], "}"}]}], "]"}]], "Input"],

Cell["\<\
If you need more resolusion modify PlotPoints, for a 400x400 pixels image use \
PlotPoints\[Rule]400:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"MandelbrotPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "0.5"}], ",", "0.75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1.25"}], ",", "0"}], "}"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "400"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"NewtonRootsPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"ColorFunction", "->", "Hue"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"NewtonRootsPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"Order", "\[Rule]", "7"}], ",", 
   RowBox[{"ColorFunction", "->", "Hue"}]}], "]"}]], "Input"],

Cell["\<\
The julia set with const\[Rule]-0.74543+0.11301*I apears in an article of \
\"Investigaci\[OAcute]n y Ciencia\" (Spanish version of \"Sientific \
America\"):\
\>", "Text"],

Cell[BoxData[
 RowBox[{"JuliaPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "0.9"}], ",", "0.9"}], "}"}], ",", 
   RowBox[{"Const", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "0.74543"}], "+", 
     RowBox[{"0.11301", "I"}]}]}], ",", 
   RowBox[{"ColorFunction", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"RGBColor", "[", 
       RowBox[{"#", ",", "0", ",", "0"}], "]"}], "&"}], ")"}]}], ",", 
   RowBox[{"Maxiter", "->", "512"}]}], "]"}]], "Input"],

Cell["\<\
You can make copntour plots of the fractals, for example, the contour plot of \
the Julia set is:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"JuliaContourPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "200"}]}], "]"}]], "Input"],

Cell["\<\
The next, plot the contour whit value 70 of one of the above examples:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"JuliaContourPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "0.9"}], ",", "0.9"}], "}"}], ",", 
   RowBox[{"Const", "->", 
    RowBox[{
     RowBox[{"-", "0.74543"}], "+", 
     RowBox[{"0.11301", "*", "I"}]}]}], ",", 
   RowBox[{"ColorFunction", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"RGBColor", "[", 
       RowBox[{"#", ",", "0", ",", "0"}], "]"}], "&"}], ")"}]}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "256"}], ",", 
   RowBox[{"Contours", "\[Rule]", 
    RowBox[{"{", "60", "}"}]}]}], "]"}]], "Input"],

Cell["This plot five contours of Newton-Raphson fractal:", "Text"],

Cell[BoxData[
 RowBox[{"NewtonRootsContourPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "256"}], ",", 
   RowBox[{"Maxiter", "\[Rule]", "256"}], ",", 
   RowBox[{"Contours", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[TextData[{
 "If you need contour contour shading use ",
 StyleBox["ContourShading", "MR"],
 " ->True option, and if you want a particular form of coloring, use  \
ColorFunction option:"
}], "Text"],

Cell[BoxData[
 RowBox[{"NewtonRootsContourPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "256"}], ",", 
   RowBox[{"Maxiter", "\[Rule]", "256"}], ",", 
   RowBox[{"Contours", "\[Rule]", "5"}], ",", 
   RowBox[{"ContourShading", "\[Rule]", "True"}], ",", " ", 
   RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]], "Input"]
},
WindowSize->{738, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 20, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 163, 3, 31, "Input"],
Cell[734, 26, 172, 3, 47, "Text"],
Cell[909, 31, 253, 8, 31, "Input"],
Cell[1165, 41, 313, 9, 31, "Input"],
Cell[1481, 52, 258, 8, 31, "Input"],
Cell[1742, 62, 125, 3, 29, "Text"],
Cell[1870, 67, 309, 9, 31, "Input"],
Cell[2182, 78, 300, 9, 31, "Input"],
Cell[2485, 89, 344, 10, 31, "Input"],
Cell[2832, 101, 181, 4, 47, "Text"],
Cell[3016, 107, 589, 18, 52, "Input"],
Cell[3608, 127, 121, 3, 29, "Text"],
Cell[3732, 132, 311, 9, 31, "Input"],
Cell[4046, 143, 94, 2, 29, "Text"],
Cell[4143, 147, 677, 20, 52, "Input"],
Cell[4823, 169, 66, 0, 29, "Text"],
Cell[4892, 171, 404, 11, 52, "Input"],
Cell[5299, 184, 202, 5, 47, "Text"],
Cell[5504, 191, 519, 13, 52, "Input"]
}
]
*)

(* End of internal cache information *)
